<?php

/**
 * @package EasyStore.Site
 * @subpackage com_easystore
 *
 * @copyright (C) 2023 JoomShaper. <https: //www.joomshaper.com>
 * @license GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace JoomShaper\Component\EasyStore\Site\Traits;

use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Filesystem\Path;
use Joomla\Database\DatabaseInterface;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects


trait ProductMedia
{
    public static function getMedia(int $productId)
    {
        $db    = Factory::getContainer()->get(DatabaseInterface::class);
        $query = $db->getQuery(true);

        $query->select(['id', 'product_id', 'name', 'is_featured', 'src', 'alt_text', 'width', 'height'])
            ->from($db->quoteName('#__easystore_media'))
            ->where($db->quoteName('product_id') . ' = ' . $productId)
            ->order($db->quoteName('ordering') . ' ASC');

        $db->setQuery($query);

        try {
            $media = $db->loadObjectList();
        } catch (\Throwable $e) {
            throw $e;
        }

        if (!empty($media)) {
            foreach ($media as &$item) {
                $item->src = Path::clean(Uri::root(true) . '/' . $item->src);
            }

            unset($item);
        }

        $thumbnail = [];

        $thumbnail = array_values(
            array_filter($media, function ($item) {
                return $item->is_featured;
            })
        );

        return (object) [
            'gallery'   => $media,
            'thumbnail' => reset($thumbnail) ?: null,
        ];
    }

    public static function getThumbnail($images)
    {
        if (empty($images)) {
            return (object) [
                'image' => '',
                'title' => '',
            ];
        }

        $thumb = reset($images);

        return (object) [
            'image' => $thumb->product_image,
            'title' => $thumb->alt,
        ];
    }
}
